<?php
    class EdeSMSLib {
        private $credentials,$username,$password;
        public $error;	// This error message output
        public $timeout = 200; // This timeout
        public $rid; 		// This Report ID
        private $url;		// This Data URL


        public function __construct($username, $password) {
            $this->username = $username;
            $this->password = $password;
            $this->credentials = $username .":". $password;
            $this->url 	  = "http://edesms.com/Api/";
        }

        private function curl_use($site_url='',$post_data=''){
            $header = array(
                "Content-type: text/xml",
                "Accept: text/xml",
                "Cache-Control: no-cache",
                "Pragma: no-cache",
                "SOAPAction: '" . $site_url . "'",
                "Content-length: ".strlen($post_data),
            );

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL,$site_url);
            if($post_data){
                curl_setopt($ch, CURLOPT_POST, 1);
                curl_setopt($ch, CURLOPT_POSTFIELDS,$post_data);
            }
            curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
            curl_setopt($ch, CURLOPT_HEADER, 0);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
            curl_setopt($ch, CURLOPT_TIMEOUT, $this->timeout);
            curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC) ;
            curl_setopt($ch, CURLOPT_USERPWD, $this->credentials);
            curl_setopt($ch, CURLOPT_SSLVERSION,3);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
            curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
            $result = curl_exec($ch);
            if(curl_errno($ch)){
                $this->error = curl_error($ch);
                $result = false;
            }
            return $result;
        }


        public function Submit($title = NULL,$message = NULL,$numbers = []){
            if(!is_array($numbers)) $numbers = [$numbers];

            $numberContent = "";
            foreach ($numbers as &$x) {
                $numberContent .= "<d2p1:string>" . $x . "</d2p1:string>";
            }

            $xmlString = "
<Submit xmlns:i='http://www.w3.org/2001/XMLSchema-instance' xmlns='SmsApi'>
   <Credential>
        <Password>" . $this->password . "</Password>
        <Username>" . $this->username . "</Username>
   </Credential>
   <DataCoding>Default</DataCoding>
   <Header>
        <From>" . $title . "</From>
        <ScheduledDeliveryTime></ScheduledDeliveryTime>
        <ValidityPeriod>0</ValidityPeriod>
   </Header>
   <Message>" . $message . "</Message>
   <To xmlns:d2p1='http://schemas.microsoft.com/2003/10/Serialization/Arrays'>".$numberContent ."</To>
 </Submit>
";


            $outcome = $this->curl_use($this->url.'Submit',$xmlString);
            if($outcome){

                preg_match('/\<MessageId\>(.*?)\<\/MessageId\>/',$outcome,$matches1);
                preg_match('/\<Description\>(.*?)\<\/Description\>/',$outcome,$matches2);
                $rid        = isset($matches1[1]) ? $matches1[1] : 0;
                $msg        = isset($matches2[1]) ? $matches2[1] : 'Bilinmeyen bir hata oluştu.';
                if(!$rid){
                    $this->error = $msg;
                    return false;
                }
                $this->rid = $rid;

                return true;
            }else{
                $this->error = "API tarafından yanıt dönmedi.";
                return false;
            }

        }

        public function Balance(){
            $xml_data = "
<GetBalance xmlns:i='http://www.w3.org/2001/XMLSchema-instance' xmlns='SmsApi'>
    <Credential>
          <Password>" . $this->password . "</Password>
          <Username>" . $this->username . "</Username>
    </Credential>
 </GetBalance>
";
            $outcome = $this->curl_use($this->url.'GetBalance',$xml_data);
            if(!$outcome){
                $this->error = "API tarafından yanıt dönmedi.";
                return 0;
            }
            preg_match('/\<Limit\>(.*?)\<\/Limit\>/',$outcome,$matches);
            return isset($matches[1]) ? $matches[1] : 0;
        }

        public function ReportLook($rid){
            $xml_data = "
<Query xmlns:i='http://www.w3.org/2001/XMLSchema-instance' xmlns='SmsApi'>
   <Credential>
        <Password>" . $this->password . "</Password>
        <Username>" . $this->username . "</Username>
   </Credential>
   <MSISDN></MSISDN>
   <MessageId>" . $rid . "</MessageId>
</Query>
";

            $reports    = [];

            $outcome = $this->curl_use($this->url.'Query',$xml_data);
            if($outcome){
                $outcome        = explode("\r\n",$outcome);

                foreach($outcome AS $row){
                 $row   = explode(" ",$row);
                 $reports[]   = $row;
                }

            }else{
                $this->error = 'API tarafından yanıt alınamadı.';
                return false;
            }

            if($reports){
                $iletilen   = [];
                $bekleyen   = [];
                $hatali     = [];

                foreach($reports AS $row){
                    if($row[0]){
                        if($row[1] == 0) $bekleyen[] = $row[0];
                        elseif($row[1] == 1) $iletilen[] = $row[0];
                        elseif($row[1] == 2) $hatali[] = $row[0];
                    }
                }
                return [
                    'iletilen' => $iletilen,
                    'bekleyen' => $bekleyen,
                    'hatali'   => $hatali,
                ];
            }else return false;
        }
    }